==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ChartSeriesEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { ChartSeriesEventArgsDescription } from "./ChartSeriesEventArgsDescription";
/**
 * @hidden
 */
export let ChartSeriesEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSeriesEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSeriesEventArgsDescriptionMetadata.a == null) {
                ChartSeriesEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSeriesEventArgsDescriptionMetadata.c(ChartSeriesEventArgsDescriptionMetadata.a);
            }
            if (a.k(ChartSeriesEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ChartSeriesEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
        }
        static d(a) {
            ChartSeriesEventArgsDescriptionMetadata.b(a);
            a.ad("ChartSeriesEventArgs", () => new ChartSeriesEventArgsDescription());
            a.ac("ChartSeriesEventArgs", ChartSeriesEventArgsDescriptionMetadata.a);
        }
    }
    ChartSeriesEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartSeriesEventArgsDescriptionMetadata, 'ChartSeriesEventArgsDescriptionMetadata');
    ChartSeriesEventArgsDescriptionMetadata.a = null;
    return ChartSeriesEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/ChartSeriesEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { ChartSeriesEventArgsDescription } from "./ChartSeriesEventArgsDescription";
/**
 * @hidden
 */
export let ChartSeriesEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSeriesEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSeriesEventArgsDescriptionMetadata.a == null) {
                ChartSeriesEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSeriesEventArgsDescriptionMetadata.c(ChartSeriesEventArgsDescriptionMetadata.a);
            }
            if (a.k(ChartSeriesEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ChartSeriesEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
        }
        static d(a) {
            ChartSeriesEventArgsDescriptionMetadata.b(a);
            a.ae("ChartSeriesEventArgs", () => new ChartSeriesEventArgsDescription());
            a.ad("ChartSeriesEventArgs", ChartSeriesEventArgsDescriptionMetadata.a);
        }
    }
    ChartSeriesEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartSeriesEventArgsDescriptionMetadata, 'ChartSeriesEventArgsDescriptionMetadata');
    ChartSeriesEventArgsDescriptionMetadata.a = null;
    return ChartSeriesEventArgsDescriptionMetadata;
})();
